>From eaac203b40988272d95a754eaddf6b68aecb181c Mon Sep 17 00:00:00 2001
From: Joerg Albert <jal2@gmx.de>
Date: Sun, 1 May 2016 13:17:14 +0000
Subject: [PATCH 2/2] add workaround for the problem that the KB9012 replies
 all zeros on each second start

---
 edi.c |   21 +++++++++++++++++++++
 1 file changed, 21 insertions(+)

diff --git a/edi.c b/edi.c
index 85e5178..05796ed 100644
--- a/edi.c
+++ b/edi.c
@@ -67,12 +67,28 @@ static int edi_read_byte(struct flashctx *flash, unsigned short address, unsigne
 
 	edi_read_cmd(cmd, address);
 
+	//	msg_pdbg("%s: buffer length 0x%x\n", __func__, sizeof(buffer));
+
 	rc = spi_send_command(flash, sizeof(cmd), sizeof(buffer), cmd, buffer);
 	if (rc) {
 		msg_perr("EDI: %s: spi_send_command failed with %d\n", __func__, rc);
 		return -1;
 	}
 
+#if 0
+	msg_pdbg("%s: read buffer:", __func__);
+	for(i=0; i < sizeof(buffer); i++) {
+	  msg_pdbg(" %02x", buffer[i]);
+	}
+	msg_pdbg("\n");
+#endif
+
+	/* I sometimes see the chip return a buffer of all zeros.
+	   It works correctly with the second try.
+	*/
+	if (buffer[0] == 0)
+	  return -2;
+
 	idx = 0;
 
 	for (i = 0; i < sizeof(buffer); i++) {
@@ -109,6 +125,11 @@ static int edi_read(struct flashctx *flash, unsigned short address, unsigned cha
 
 	do {
 		rc = edi_read_byte(flash, address, data);
+		
+		/* dirty workaround for my problem that the chip answers all zeros on each second start ... */
+		if (rc == -2)
+		  rc = edi_read_byte(flash, address, data);
+
 		if (rc == -EDI_NOT_READY) {
 			/*
 			 * Buffer size is increased, one step at a time,
-- 
1.7.10.4

